@@ -92,6 +92,7 @@ static const char* openCLHandleData(OpenCLData* data, FFOpenCLResult* result)
             ffStrbufInit(&gpu->vendor);
             ffStrbufInit(&gpu->driver);
             ffStrbufInit(&gpu->platformApi);
+            ffStrbufInit(&gpu->memoryType);
             gpu->index = FF_GPU_INDEX_UNSET;
             gpu->temperature = FF_GPU_TEMP_UNSET;
             gpu->coreCount = FF_GPU_CORE_COUNT_UNSET;
@@ -112,7 +113,7 @@ static const char* openCLHandleData(OpenCLData* data, FFOpenCLResult* result)
             {
                 cl_uint vendorId;
                 if (data->ffclGetDeviceInfo(deviceID, CL_DEVICE_VENDOR_ID, sizeof(vendorId), &vendorId, NULL) == CL_SUCCESS)
-                    ffStrbufSetStatic(&gpu->vendor, ffGetGPUVendorString(vendorId));
+                    ffStrbufSetStatic(&gpu->vendor, ffGPUGetVendorString(vendorId));
                 if (gpu->vendor.length == 0 && data->ffclGetDeviceInfo(deviceID, CL_DEVICE_VENDOR, sizeof(buffer), buffer, NULL) == CL_SUCCESS)
                     ffStrbufSetS(&gpu->vendor, buffer);
             }
