@@ -76,7 +76,7 @@ static const char* detectWifiWithNm(FFWifiResult* item, FFstrbuf* buffer)
         dbus.lib->ffdbus_message_unref(device);
     }
 
-    if (item->conn.txRate != item->conn.txRate)
+    if (item->conn.txRate == -DBL_MAX)
     {
         FF_DEBUG("Getting bitrate from NetworkManager");
         uint32_t bitrate;
@@ -162,7 +162,7 @@ static const char* detectWifiWithNm(FFWifiResult* item, FFstrbuf* buffer)
         }
         else if (ffStrEquals(key, "Strength"))
         {
-            if (item->conn.signalQuality != item->conn.signalQuality)
+            if (item->conn.signalQuality == -DBL_MAX)
             {
                 FF_DEBUG("Found Strength property");
                 uint32_t strengthPercent;
@@ -314,14 +314,14 @@ static const char* detectWifiWithIw(FFWifiResult* item, FFstrbuf* buffer)
     ffStrbufClear(buffer);
     if(ffParsePropLines(output.chars, "rx bitrate: ", buffer))
     {
-        item->conn.rxRate = ffStrbufToDouble(buffer);
+        item->conn.rxRate = ffStrbufToDouble(buffer, -DBL_MAX);
         FF_DEBUG("RX bitrate: %.2f Mbps", item->conn.rxRate);
     }
 
     ffStrbufClear(buffer);
     if(ffParsePropLines(output.chars, "tx bitrate: ", buffer))
     {
-        item->conn.txRate = ffStrbufToDouble(buffer);
+        item->conn.txRate = ffStrbufToDouble(buffer, -DBL_MAX);
         FF_DEBUG("TX bitrate: %.2f Mbps (raw: %s)", item->conn.txRate, buffer->chars);
 
         if(ffStrbufContainS(buffer, " EHT-MCS "))
@@ -548,9 +548,9 @@ const char* ffDetectWifi(FF_MAYBE_UNUSED FFlist* result)
         ffStrbufInit(&item->conn.bssid);
         ffStrbufInit(&item->conn.protocol);
         ffStrbufInit(&item->conn.security);
-        item->conn.signalQuality = 0.0/0.0;
-        item->conn.rxRate = 0.0/0.0;
-        item->conn.txRate = 0.0/0.0;
+        item->conn.signalQuality = -DBL_MAX;
+        item->conn.rxRate = -DBL_MAX;
+        item->conn.txRate = -DBL_MAX;
         item->conn.channel = 0;
         item->conn.frequency = 0;
 
