@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_BLUETOOTHRADIO_MODULE_NAME "BluetoothRadio"
 
 void ffPrintBluetoothRadio(FFBluetoothRadioOptions* options);
 void ffInitBluetoothRadioOptions(FFBluetoothRadioOptions* options);
 void ffDestroyBluetoothRadioOptions(FFBluetoothRadioOptions* options);
+
+extern FFModuleBaseInfo ffBluetoothRadioModuleInfo;
