@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_CAMERA_MODULE_NAME "Camera"
 
 void ffPrintCamera(FFCameraOptions* options);
 void ffInitCameraOptions(FFCameraOptions* options);
 void ffDestroyCameraOptions(FFCameraOptions* options);
+
+extern FFModuleBaseInfo ffCameraModuleInfo;
