@@ -1,6 +1,6 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_DISKIO_MODULE_NAME "DiskIO"
 
@@ -9,3 +9,5 @@ void ffPrepareDiskIO(FFDiskIOOptions* options);
 void ffPrintDiskIO(FFDiskIOOptions* options);
 void ffInitDiskIOOptions(FFDiskIOOptions* options);
 void ffDestroyDiskIOOptions(FFDiskIOOptions* options);
+
+extern FFModuleBaseInfo ffDiskIOModuleInfo;
