@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_INITSYSTEM_MODULE_NAME "InitSystem"
 
 void ffPrintInitSystem(FFInitSystemOptions* options);
 void ffInitInitSystemOptions(FFInitSystemOptions* options);
 void ffDestroyInitSystemOptions(FFInitSystemOptions* options);
+
+extern FFModuleBaseInfo ffInitSystemModuleInfo;
