@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_PHYSICALDISK_MODULE_NAME "PhysicalDisk"
 
 void ffPrintPhysicalDisk(FFPhysicalDiskOptions* options);
 void ffInitPhysicalDiskOptions(FFPhysicalDiskOptions* options);
 void ffDestroyPhysicalDiskOptions(FFPhysicalDiskOptions* options);
+
+extern FFModuleBaseInfo ffPhysicalDiskModuleInfo;
