@@ -81,39 +81,22 @@ void ffPrintPlayer(FFPlayerOptions* options)
     }
 }
 
-bool ffParsePlayerCommandOptions(FFPlayerOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_PLAYER_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    return false;
-}
-
 void ffParsePlayerJsonObject(FFPlayerOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
-        ffPrintError(FF_PLAYER_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        ffPrintError(FF_PLAYER_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
 void ffGeneratePlayerJsonConfig(FFPlayerOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyPlayerOptions))) FFPlayerOptions defaultOptions;
-    ffInitPlayerOptions(&defaultOptions);
-
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 }
 
 void ffGeneratePlayerJsonResult(FF_MAYBE_UNUSED FFMediaOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
@@ -121,10 +104,21 @@ void ffGeneratePlayerJsonResult(FF_MAYBE_UNUSED FFMediaOptions* options, yyjson_
     yyjson_mut_obj_add_str(doc, module, "error", "Player module is an alias of Media module");
 }
 
-static FFModuleBaseInfo ffModuleInfo = {
+void ffInitPlayerOptions(FFPlayerOptions* options)
+{
+    ffOptionInitModuleArg(&options->moduleArgs, "󰥠");
+}
+
+void ffDestroyPlayerOptions(FFPlayerOptions* options)
+{
+    ffOptionDestroyModuleArg(&options->moduleArgs);
+}
+
+FFModuleBaseInfo ffPlayerModuleInfo = {
     .name = FF_PLAYER_MODULE_NAME,
     .description = "Print music player name",
-    .parseCommandOptions = (void*) ffParsePlayerCommandOptions,
+    .initOptions = (void*) ffInitPlayerOptions,
+    .destroyOptions = (void*) ffDestroyPlayerOptions,
     .parseJsonObject = (void*) ffParsePlayerJsonObject,
     .printModule = (void*) ffPrintPlayer,
     .generateJsonResult = (void*) ffGeneratePlayerJsonResult,
@@ -136,14 +130,3 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"URL name", "url"},
     }))
 };
-
-void ffInitPlayerOptions(FFPlayerOptions* options)
-{
-    options->moduleInfo = ffModuleInfo;
-    ffOptionInitModuleArg(&options->moduleArgs, "󰥠");
-}
-
-void ffDestroyPlayerOptions(FFPlayerOptions* options)
-{
-    ffOptionDestroyModuleArg(&options->moduleArgs);
-}
