@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_TERMINAL_MODULE_NAME "Terminal"
 
 void ffPrintTerminal(FFTerminalOptions* options);
 void ffInitTerminalOptions(FFTerminalOptions* options);
 void ffDestroyTerminalOptions(FFTerminalOptions* options);
+
+extern FFModuleBaseInfo ffTerminalModuleInfo;
